##  Optional: Create a Custom Application Rationalization Dashboard
Create an overview with the most important data points and evaluations for your rationalization initiative. You can consider the following data points that you collected and evaluated while going through the rationalization step-by-step:
  * Functional fit chart
  * Technical fit chart
  * Landscape report by TIME in the following versions:
    * Before
    * After the application rationalization
  * Landscape report with total cost of ownership of applications in the following versions:
    * By business capability
    * By time classification
  * Application Portfolio report by TIME and business criticality with the total cost of ownership of applications
  * Initiative roadmap with drill-down to affected applications


**Tip**
Use the pre-defined dashboard for application rationalization as your starting point. Copy and adjust the dashboard to your organization-specific requirements.
To learn how to setup your dashboard, see [Dashboards](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.").
![Custom application Rationalization dashboard with application landscape report showing TCO for applications allocated to business capabilities, bubble chart with TCO for the bubble size, and application landscape report showing application cost clustered by TIME](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio23a0ff840d1a4f6bbd20ca13cd92cb7b_HiRes.png)
